@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: Util.py 11201 2018-08-12 14:45:23Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Date: 2018-08-12 23:45:23 +0900 (週日, 12 八月 2018) $
+# $Revision: 11201 $
 
 import hashlib
 
@@ -67,6 +67,45 @@ class Pay2GoMPGAPI(object):
 
         return payment
 
+CATHAPBK_SERVICE_URL = \
+    'https://sslpayment.uwccb.com.tw/EPOSService/Payment/OrderInitial.aspx'
+
+from django.template.loader import get_template
+from django.template import Context
+
+class CathaybkAPI(object):
+
+    def __init__(self, merchantId, cubkey):
+        self.merchantId = merchantId
+        self.cubkey = cubkey
+
+    def generateCheckValue(self, data):
+        checkValue = hashlib.md5(
+            self.merchantId + data['ORDERNUMBER'] + 
+            str(data['AMOUNT']) + self.cubkey).hexdigest()
+        return checkValue
+
+    def buildXml(self, data):
+        temp = get_template('shop/payment/Cathaybk.xml')
+        context = Context({
+            'data': data,
+            'checkValue': self.generateCheckValue(data),
+            'merchantId': self.merchantId,
+        })
+        xml = temp.render(context)
+        return xml
+
+    def buildForm(self, data):
+        xml = self.buildXml(data)
+        temp = get_template('shop/payment/Cathaybk.html')
+        context = Context({
+            'xml': xml,
+            'apiUrl': CATHAPBK_SERVICE_URL,
+        })
+        form = temp.render(context)
+        return form
+        
+
 
 class Payment(object):
 
