@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11196 2018-08-06 09:02:05Z Lavender $
+# $Id: __init__.py 11201 2018-08-12 14:45:23Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-08-06 18:02:05 +0900 (週一, 06 八月 2018) $
-# $Revision: 11196 $
+# $Date: 2018-08-12 23:45:23 +0900 (週日, 12 八月 2018) $
+# $Revision: 11201 $
 
 import os
 import sys
@@ -79,14 +79,7 @@ CKEDITOR_CONFIGS = {
 
             ]},
         ],
-        'toolbar': 'YourCustomToolbarConfig',  # put selected toolbar config here
-        # 'toolbarGroups': [{ 'name': 'document', 'groups': [ 'mode', 'document', 'doctools' ] }],
-        # 'height': 291,
-        # 'width': '100%',
-        # 'filebrowserWindowHeight': 725,
-        # 'filebrowserWindowWidth': 940,
-        # 'toolbarCanCollapse': True,
-        # 'mathJaxLib': '//cdn.mathjax.org/mathjax/2.2-latest/MathJax.js?config=TeX-AMS_HTML',
+        'toolbar': 'YourCustomToolbarConfig',  
         'tabSpaces': 4,
         'extraPlugins': ','.join([
             'uploadimage', # the upload image feature
@@ -231,7 +224,8 @@ def attachSettings(settingsDict, enablePaypal=False):
         settingsDict['OSCAR_DEFAULT_CURRENCY'] = 'USD'
     #=========================================================================
     # Oscar default settings 
-    # __import__ 模組的用法與官方文件有落差，可能是使用時帶入參數有誤，先以目前的寫法帶過
+    # __import__ 模組的用法與官方文件有落差，可能是使用時帶入參數有誤，
+    # 先以目前的寫法帶過
     # see #2784
     addOscarDefaultsPackages = {}
     oscarDefaultsPackages = __import__(
@@ -256,6 +250,10 @@ def attachSettings(settingsDict, enablePaypal=False):
     if 'IUNO_SHOP_SPGATEWAY_ENABLE' in settingsDict:
         spgatewayEnable = settingsDict['IUNO_SHOP_SPGATEWAY_ENABLE']
 
+    cathaybkEnable = False
+    if 'IUNO_SHOP_CATHAYBK_ENABLE' in settingsDict:
+        cathaybkEnable = settingsDict['IUNO_SHOP_CATHAYBK_ENABLE']
+
     ADDING_OSCAR_DASHBOARD_NAVIGATION = {
         'label': _('Payment'),
         'icon': 'icon-globe',
@@ -307,6 +305,13 @@ def attachSettings(settingsDict, enablePaypal=False):
             'access_fn': \
                 lambda user, url_name, url_args, url_kwargs: user.is_staff,
         })
+    if cathaybkEnable:
+        ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
+            'label': _('Cathay credit transactions'),
+            'url_name': 'cathaybkCreditTransaction',
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+        })
 
     if enablePaypal or ecpayEnable or allpayEnable or spgatewayEnable:
         if 'OSCAR_DASHBOARD_NAVIGATION' in settingsDict:
@@ -365,6 +370,10 @@ def attachShopURLs(settings, urlpatterns):
     if hasattr(settings, 'IUNO_SHOP_SPGATEWAY_ENABLE'):
         spgatewayEnable = settings.IUNO_SHOP_SPGATEWAY_ENABLE
 
+    cathaybkEnable = False
+    if hasattr(settings, 'IUNO_SHOP_CATHAYBK_ENABLE'):
+        cathaybkEnable = settings.IUNO_SHOP_CATHAYBK_ENABLE
+
     if paypalEnable:
         urlpatterns += patterns('',          
             url(r'^shop/dashboard/paypal/express/', application.urls),
@@ -373,6 +382,11 @@ def attachShopURLs(settings, urlpatterns):
             url(r'^checkout/paypal/', include('paypal.express.urls')),
         )
 
+    if cathaybkEnable:
+        urlpatterns += patterns('',
+            url(r'^cathaybk/preview/', views.returnCathaybkCreditXml),
+        )
+
     if ecpayEnable or allpayEnable or spgatewayEnable:
         urlpatterns += patterns('',
             url(r'^(?P<name>.*)/preview/', 
@@ -400,6 +414,14 @@ def attachShopURLs(settings, urlpatterns):
                 name='spgatewayTransaction'),
         )
 
+    if cathaybkEnable:
+        urlpatterns += patterns('',
+            url(r'^dashboard/spgateway/transaction/', 
+                staff_member_required(
+                    views.CathaybkCreditTransactionListView.as_view()),
+                name='cathaybkCreditTransaction'),
+        )
+
 # ------------------------------------------------------------------------------
 import hashlib
 import time
@@ -412,7 +434,7 @@ from django.utils.translation import ugettext_lazy as _
 from pyallpay import AllPay
 
 from Iuppiter.Encoding import utf8
-from Iuno.shop.Util import Pay2GoMPGAPI
+from Iuno.shop.Util import Pay2GoMPGAPI, CathaybkAPI
 
 ECPAY_SANDBOX_SERVICE_URL = \
                     'https://payment-stage.ecpay.com.tw/Cashier/AioCheckOut/V2'
@@ -425,6 +447,7 @@ ALLPAY_SERVICE_URL = 'https://payment.allpay.com.tw/Cashier/AioCheckOut'
 SPGATEWAY = 'spgateway'
 ALLPAY = 'allpay'
 ECPAY = 'ecpay'
+CATHAYBK = 'cathaybk'
 
 class AllPay2(AllPay):
     def gen_check_out_form(self, dict_url, auto_send=True):
@@ -454,7 +477,7 @@ def buildAPIForm(submission, request, apiName):
     scheme = request.scheme
     domain = request.META['HTTP_HOST']
 
-    if not apiName in [SPGATEWAY, ALLPAY, ECPAY]:
+    if not apiName in [SPGATEWAY, ALLPAY, ECPAY, CATHAYBK]:
         raise ValueError("Not pay api name: %s" % apiName)
 
     MERCHANT_TRADE_NO_LEN = 20
@@ -574,4 +597,19 @@ def buildAPIForm(submission, request, apiName):
             form = form.replace('allPay-Form', 'allpayForm')
             form = form.replace('allPayForm', 'allpayForm')
         
+        return form
+
+    if apiName == CATHAYBK:
+        mpg = CathaybkAPI(
+            merchantId=settings.CATHAYBK_API_MERCHANT_ID,
+            cubkey=settings.CATHAYBK_API_CUBKEY,
+        )
+
+        data = {
+            'ORDERNUMBER': merchantTradeNo,
+            'AMOUNT': int(total),
+        }
+
+        form = mpg.buildForm(data)
+                                      
         return form
\ No newline at end of file
