@@ -51,3 +51,16 @@ class SpgatewayTrade(models.Model):
          
     rtnCode = models.CharField(max_length=30)
     rtnMsg = models.CharField(max_length=30)
+
+class CathaybkCreditTrade(models.Model):
+    merchantId = models.CharField(max_length=30) # STOREID
+    merchantTradeNo = models.CharField(max_length=30) # ORDERNUMBER
+    tradeNo = models.CharField(max_length=30) # AUTHCODE
+    
+    paymentDate = models.DateTimeField() # AUTHTIME
+    
+    tradeAmt = models.IntegerField() # AMOUNT
+         
+    rtnCode = models.CharField(max_length=30) # AUTHSTATUS
+    rtnMsg = models.CharField(max_length=30) # AUTHMSG
+    cardNo = models.CharField(max_length=30) # CARDNO
